==> burrtools-0.4.1.tar.gz: burrtools-0.4.1/src/gui/view3dgroup.cpp <==
/* Burr Solver
 * Copyright (C) 2003-2008  Andreas Rver
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#include "view3dgroup.h"

#include "guigridtype.h"

#include "../lib/puzzle.h"
#include "../lib/disasmtomoves.h"

#include <FL/Fl_Pixmap.H>
#include <FL/Fl_Multiline_Output.H>

#include <math.h>

// some tool widgets, that may be swapped out later into another file

static void cb_View3dGroupSlider_stub(Fl_Widget* o, void* /*v*/) { ((LView3dGroup*)(o->parent()))->cb_slider(); }

void LView3dGroup::cb_slider(void) {
  View3D->setSize(exp(6-slider->value()));
}

static void cb_View3dGroupVoxel_stub(Fl_Widget* o, void* /*v*/) { ((LView3dGroup*)(o->parent()))->do_callback(); }

LView3dGroup::LView3dGroup(int x, int y, int w, int h, const guiGridType_c * ggt) : Fl_Group(0, 0, 50, 50), layoutable_c(x, y, w, h) {

  x = y = 0;
  w = h = 50;

  box(FL_DOWN_BOX);

  View3D = new voxelFrame_c(x, y, w-15, h);
  View3D->setDrawer(ggt->getVoxelDrawer());
  View3D->tooltip(" Rotate the puzzle by dragging with the mouse ");
  View3D->box(FL_NO_BOX);
  View3D->callback(cb_View3dGroupVoxel_stub, this);

  slider = new Fl_Slider(x+w-15, y, 15, h);
  slider->tooltip("Zoom view.");
  slider->maximum(6);
  slider->minimum(0);
  slider->step(0.01);
  slider->value(2);
  slider->callback(cb_View3dGroupSlider_stub);
  slider->clear_visible_focus();

  cb_slider();

  resizable(View3D);
  end();
}

void LView3dGroup::newGridType(const guiGridType_c * ggt) {

  View3D->setDrawer(ggt->getVoxelDrawer());
}

void LView3dGroup::showSingleShape(const puzzle_c * puz, unsigned int shapeNum) {
  View3D->showSingleShape(puz, shapeNum);
}

void LView3dGroup::showProblem(const puzzle_c * puz, unsigned int probNum, unsigned int selShape) {

  View3D->showProblem(puz, probNum, selShape);
}

void LView3dGroup::showColors(const puzzle_c * puz, voxelFrame_c::colorMode mode) {
  View3D->showColors(puz, mode);
}

void LView3dGroup::showAssembly(const puzzle_c * puz, unsigned int probNum, unsigned int solNum) {
  View3D->showAssembly(puz, probNum, solNum);
}

void LView3dGroup::showPlacement(const puzzle_c * puz, unsigned int probNum, unsigned int piece, unsigned char trans, int x, int y, int z) {

  View3D->showPlacement(puz, probNum, piece, trans, x, y, z);
}

void LView3dGroup::updatePositions(piecePositions_c *shifting) {
  View3D->updatePositions(shifting);
}

void LView3dGroup::updatePositionsOverlap(piecePositions_c *shifting) {
  View3D->updatePositionsOverlap(shifting);
}

void LView3dGroup::updateVisibility(PieceVisibility * pcvis) {
  View3D->updateVisibility(pcvis);
}

==> burrtools-0.5.1.tar.gz: burrtools-0.5.1/src/gui/view3dgroup.cpp <==
/* Burr Solver
 * Copyright (C) 2003-2009  Andreas Rver
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#include "view3dgroup.h"

#include "guigridtype.h"

#include "../lib/puzzle.h"
#include "../lib/disasmtomoves.h"

#include <FL/Fl_Pixmap.H>
#include <FL/Fl_Multiline_Output.H>

#include <math.h>

// some tool widgets, that may be swapped out later into another file

static void cb_View3dGroupSlider_stub(Fl_Widget* o, void* /*v*/) { ((LView3dGroup*)(o->parent()))->cb_slider(); }

void LView3dGroup::cb_slider(void) {
  View3D->setSize(exp(6-slider->value()));
}

static void cb_View3dGroupVoxel_stub(Fl_Widget* o, void* /*v*/) { ((LView3dGroup*)(o->parent()))->do_callback(); }

LView3dGroup::LView3dGroup(int x, int y, int w, int h, const guiGridType_c * ggt) : Fl_Group(0, 0, 50, 50), layoutable_c(x, y, w, h) {

  x = y = 0;
  w = h = 50;

  box(FL_DOWN_BOX);

  View3D = new voxelFrame_c(x, y, w-15, h);
  View3D->setDrawer(ggt->getVoxelDrawer());
  View3D->tooltip(" Rotate the puzzle by dragging with the mouse ");
  View3D->box(FL_NO_BOX);
  View3D->callback(cb_View3dGroupVoxel_stub, this);

  slider = new Fl_Slider(x+w-15, y, 15, h);
  slider->tooltip("Zoom view.");
  slider->maximum(6);
  slider->minimum(0);
  slider->step(0.01);
  slider->value(2);
  slider->callback(cb_View3dGroupSlider_stub);
  slider->clear_visible_focus();

  cb_slider();

  resizable(View3D);
  end();
}

void LView3dGroup::newGridType(const guiGridType_c * ggt) {

  View3D->setDrawer(ggt->getVoxelDrawer());
}

void LView3dGroup::showSingleShape(const puzzle_c * puz, unsigned int shapeNum) {
  View3D->showSingleShape(puz, shapeNum);
}

void LView3dGroup::showProblem(const puzzle_c * puz, unsigned int problem, unsigned int selShape) {
  View3D->showProblem(puz, problem, selShape);
}

void LView3dGroup::showColors(const puzzle_c * puz, voxelFrame_c::colorMode mode) {
  View3D->showColors(puz, mode);
}

void LView3dGroup::showAssembly(const problem_c * puz, unsigned int solNum) {
  View3D->showAssembly(puz, solNum);
}

void LView3dGroup::showPlacement(const problem_c * puz, unsigned int piece, unsigned char trans, int x, int y, int z) {
  View3D->showPlacement(puz, piece, trans, x, y, z);
}

void LView3dGroup::updatePositions(piecePositions_c *shifting) {
  View3D->updatePositions(shifting);
}

void LView3dGroup::updatePositionsOverlap(piecePositions_c *shifting) {
  View3D->updatePositionsOverlap(shifting);
}

void LView3dGroup::updateVisibility(PieceVisibility * pcvis) {
  View3D->updateVisibility(pcvis);
}

int LView3dGroup::handle(int event) {

  Fl_Group::handle(event);

  switch(event)
  {
    case FL_MOUSEWHEEL:
      slider->value(slider->value() + 0.1*Fl::e_dy);
      View3D->setSize(exp(6-slider->value()));
      return 1;
  }

  return 0;
}
